@@ -5,13 +5,13 @@ Some spiders used for testing and benchmarking
 import time
 from urllib import urlencode
 
-from scrapy.spider import BaseSpider
+from scrapy.spider import Spider
 from scrapy.http import Request
 from scrapy.item import Item
 from scrapy.contrib.linkextractors.sgml import SgmlLinkExtractor
 
 
-class MetaSpider(BaseSpider):
+class MetaSpider(Spider):
 
     name = 'meta'
 
@@ -132,3 +132,22 @@ class BrokenStartRequestsSpider(FollowAllSpider):
         self.seedsseen.append(response.meta.get('seed'))
         for req in super(BrokenStartRequestsSpider, self).parse(response):
             yield req
+
+
+class SingleRequestSpider(MetaSpider):
+
+    seed = None
+
+    def start_requests(self):
+        if isinstance(self.seed, Request):
+            yield self.seed.replace(callback=self.parse, errback=self.on_error)
+        else:
+            yield Request(self.seed, callback=self.parse, errback=self.on_error)
+
+    def parse(self, response):
+        self.meta.setdefault('responses', []).append(response)
+        if 'next' in response.meta:
+            return response.meta['next']
+
+    def on_error(self, failure):
+        self.meta['failure'] = failure
