@@ -4,32 +4,9 @@ This module contains some assorted functions used in tests
 
 import os
 
+from importlib import import_module
 from twisted.trial.unittest import SkipTest
 
-def libxml2debug(testfunction):
-    """Decorator for debugging libxml2 memory leaks inside a function.
-    
-    We've found libxml2 memory leaks are something very weird, and can happen
-    sometimes depending on the order where tests are run. So this decorator
-    enables libxml2 memory leaks debugging only when the environment variable
-    LIBXML2_DEBUGLEAKS is set.
-
-    """
-    try:
-        import libxml2
-    except ImportError:
-        return testfunction
-    def newfunc(*args, **kwargs):
-        libxml2.debugMemory(1)
-        testfunction(*args, **kwargs)
-        libxml2.cleanupParser()
-        leaked_bytes = libxml2.debugMemory(0) 
-        assert leaked_bytes == 0, "libxml2 memory leak detected: %d bytes" % leaked_bytes
-
-    if 'LIBXML2_DEBUGLEAKS' in os.environ:
-        return newfunc
-    else:
-        return testfunction
 
 def assert_aws_environ():
     """Asserts the current environment is suitable for running AWS testsi.
@@ -37,7 +14,7 @@ def assert_aws_environ():
     """
     try:
         import boto
-    except ImportError, e:
+    except ImportError as e:
         raise SkipTest(str(e))
 
     if 'AWS_ACCESS_KEY_ID' not in os.environ:
@@ -63,7 +40,7 @@ def get_crawler(settings_dict=None):
 def get_pythonpath():
     """Return a PYTHONPATH suitable to use in processes so that they find this
     installation of Scrapy"""
-    scrapy_path = __import__('scrapy').__path__[0]
+    scrapy_path = import_module('scrapy').__path__[0]
     return os.path.dirname(scrapy_path) + os.pathsep + os.environ.get('PYTHONPATH', '')
 
 def get_testenv():
